==> gitlab_16.11.6.orig.tar.bz2: gitlab-foss-v16.11.6/qa/qa/specs/features/browser_ui/3_create/web_ide/add_new_directory_in_web_ide_spec.rb <==
# frozen_string_literal: true

module QA
  RSpec.describe 'Create', product_group: :ide do
    describe 'Add a directory in Web IDE' do
      let(:project) { create(:project, :with_readme, name: 'webide-add-directory-project') }

      before do
        Flow::Login.sign_in
        project.visit!
      end

      context 'when a directory with the same name already exists' do
        let(:directory_name) { 'first_directory' }

        before do
          create(:commit, project: project, actions: [
            { action: 'create', file_path: 'first_directory/test_file.txt', content: 'Test file content' }
          ])

          project.visit!
          Page::Project::Show.perform(&:open_web_ide!)
          Page::Project::WebIDE::VSCode.perform(&:wait_for_ide_to_load)
        end

        it 'throws an error', testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/386760' do
          Page::Project::WebIDE::VSCode.perform do |ide|
            ide.create_new_folder(directory_name)

            expect(ide).to have_message('A file or folder first_directory already exists at this location.')
          end
        end
      end

      context 'when user adds a new empty directory' do
        let(:directory_name) { 'new_empty_directory' }

        before do
          Page::Project::Show.perform(&:open_web_ide!)
          Page::Project::WebIDE::VSCode.perform(&:wait_for_ide_to_load)
        end

        it 'shows successfully but not able to be committed',
          testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/386761' do
          Page::Project::WebIDE::VSCode.perform do |ide|
            ide.create_new_folder(directory_name)
            ide.commit_toggle(directory_name)

            expect(ide).to have_message('No changes found. Not able to commit.')
          end
        end
      end
    end
  end
end

==> gitlab_17.3.5.orig.tar.bz2: gitlab-foss-v17.3.5/qa/qa/specs/features/browser_ui/3_create/web_ide/add_new_directory_in_web_ide_spec.rb <==
# frozen_string_literal: true

module QA
  RSpec.describe 'Create', product_group: :remote_development do
    describe 'Add a directory in Web IDE' do
      let(:project) { create(:project, :with_readme, name: 'webide-add-directory-project') }

      before do
        Flow::Login.sign_in
        project.visit!
      end

      context 'when a directory with the same name already exists' do
        let(:directory_name) { 'first_directory' }

        before do
          create(:commit, project: project, actions: [
            { action: 'create', file_path: 'first_directory/test_file.txt', content: 'Test file content' }
          ])

          project.visit!
          Page::Project::Show.perform(&:open_web_ide!)
          Page::Project::WebIDE::VSCode.perform do |ide|
            ide.wait_for_ide_to_load('README.md')
          end
        end

        it 'throws an error', :blocking, testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/386760' do
          Page::Project::WebIDE::VSCode.perform do |ide|
            ide.create_new_folder(directory_name)

            expect(ide).to have_message('A file or folder first_directory already exists at this location.')
          end
        end
      end

      context 'when user adds a new empty directory' do
        let(:directory_name) { 'new_empty_directory' }

        before do
          Page::Project::Show.perform(&:open_web_ide!)
          Page::Project::WebIDE::VSCode.perform(&:wait_for_ide_to_load)
        end

        it 'shows successfully but not able to be committed', :blocking,
          testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/386761' do
          Page::Project::WebIDE::VSCode.perform do |ide|
            ide.create_new_folder(directory_name)
            ide.commit_toggle(directory_name)

            expect(ide).to have_message('No changes found. Not able to commit.')
          end
        end
      end
    end
  end
end
